import { CompletionCtx } from '@genesiscommunitysuccess/custom-elements-lsp/out/main/plugins/export-interface';
import { SemanticContext, Snippet } from '../constants';
/**
 * Returns the DOM hierarchy at the cursor position up to the root of the text.
 * @param ctx - The completion context
 * @returns node names in order from cursor to root
 *
 * @remarks May return malformed result if the html markup is not valid. e.g. missing
 * closing tags.
 */
export declare function tryGetCursorHTMLContext(ctx: CompletionCtx): string[];
/**
 * Returns a set of semantic contexts based on the html context.
 * @param htmlContext - The html context from `tryGetCursorHTMLContext`
 * @param designSystemPrefix - The prefix of the design system, used to match tag names
 * @returns A set of semantic contexts
 */
export declare function getSemanticContext(htmlContext: string[], designSystemPrefix: string): SemanticContext[];
/**
 * Applies any rules set on a snippet depending on the semantic context.
 * @param rules - The rules set on the snippet
 * @param semanticCtx - The semantic context
 * @returns The sort text for the snippet, or null if the snippet should not be shown. `0` is a snippet with the highest precedent, `9` is the lowest.
 */
export declare function applySemanticRules(rules: Snippet['rules'], semanticCtx: SemanticContext[], baseSorting: number): string | null;
export declare const markCursorInTemplate: (templateText: string, pos: number) => string;
//# sourceMappingURL=index.d.ts.map