"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FoundationCompletionsService = void 0;
const tsserverlibrary_1 = require("typescript/lib/tsserverlibrary");
const constants_1 = require("../constants");
const utils_1 = require("../utils");
class FoundationCompletionsService {
    constructor(logger, services, designSystemPrefix) {
        this.logger = logger;
        this.services = services;
        this.designSystemPrefix = designSystemPrefix;
        this.logger.log('Setting up Foundation Completions Service');
    }
    getCompletionsAtPosition(completions, ctx) {
        const { key } = ctx.typeAndParam;
        let entries = completions.entries;
        switch (key) {
            case 'tag-name':
                entries = entries.concat(this.getComponentSnippets(ctx));
        }
        return Object.assign(Object.assign({}, completions), { entries });
    }
    /**
     * Converts snippets into completions, applying rules based on the semantic context.
     */
    getComponentSnippets(ctx) {
        const htmlContext = (0, utils_1.tryGetCursorHTMLContext)(ctx);
        const semanticContext = (0, utils_1.getSemanticContext)(htmlContext, this.designSystemPrefix);
        return (0, constants_1.getSnippets)(this.designSystemPrefix).reduce((acum, { name, snippet, description, rules, baseSorting }) => {
            const appliedRules = (0, utils_1.applySemanticRules)(rules, semanticContext, baseSorting);
            if (appliedRules === null)
                return acum;
            return acum.concat({
                name,
                insertText: snippet,
                kind: tsserverlibrary_1.ScriptElementKind.classElement,
                isSnippet: true,
                sortText: appliedRules,
                labelDetails: {
                    description,
                },
            });
        }, []);
    }
}
exports.FoundationCompletionsService = FoundationCompletionsService;
